embassy-stm32

Crates

git

Versions

stm32c551ce

Flavors

TIM1

Struct TIM1 

pub struct TIM1 { /* private fields */ }
TIM1 peripheral

Implementations

Source

impl TIM1

pub const unsafe fn steal() -> Peri<'static, Self>

Unsafely create an instance of this peripheral out of thin air.

Safety

You must ensure that you’re only using one instance of this type at a time.